@@ -42,7 +42,8 @@ SplineReg_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), base_le
 ## SplineReg_LM_Multivar ##
 ###########################
 #' @importFrom MASS ginv
-
+#' @importFrom splines splineDesign
+#' @importFrom stats lm model.matrix model.frame terms coef
 SplineReg_LM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), base_learners,
                                   weights = rep(1, NROW(Y)), InterKnotsList, n, extrList = lapply(X, range),
                                   prob = 0.95, coefficients, linear.predictors, linear_intercept = FALSE, de_mean = FALSE)
@@ -154,7 +155,7 @@ SplineReg_LM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), base
       
       # Compute t(basisMatrix2) %*% basisMatrix2 using crossprod (more efficient)
       matcb <- crossprod(basisMatrix2)
-      matcbinv <- MASS::ginv(matcb)
+      matcbinv <- ginv(matcb)
       theta <- as.numeric(matcbinv %*% crossprod(basisMatrix2, tmp$fitted.values))
       
     }
@@ -260,14 +261,15 @@ SplineReg_LM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), base
   
   resid <- Y - predicted
   # Confidence intervals
-  CI <- CI(tmp, resid, prob = 0.95, basisMatrix, basisMatrix2, predicted,
+  ci <- ci(tmp, resid, prob = 0.95, basisMatrix, basisMatrix2, predicted,
            n_obs = length(Y), type = "lm", huang = TRUE)
 
   
-  out <- list(Theta = theta, Predicted = predicted, Residuals = resid, 
-              RSS = as.numeric(crossprod(resid)), NCI = CI$NCI, Basis = basisMatrix, 
-              Polygon = list(Kn = polyknots_list, Thetas = theta[1:NCOL(basisMatrix)]), 
-              temporary = tmp, ACI = CI$ACI)
+  out <- list(theta = theta, predicted = predicted, residuals = resid, 
+              rss = as.numeric(crossprod(resid)), basis = basisMatrix,
+              nci = ci$nci, aci = ci$aci, 
+              polygon = list(Kn = polyknots_list, thetas = theta[1:NCOL(basisMatrix)]), 
+              temporary = tmp)
   return(out)
   
 }
@@ -275,6 +277,8 @@ SplineReg_LM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), base
 ############################
 ## SplineReg_GLM_Multivar ##
 ############################
+#' @importFrom splines splineDesign
+#' @importFrom stats glm coef model.frame model.matrix terms
 SplineReg_GLM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), base_learners,
                                    weights = rep(1, NROW(Y)), InterKnotsList, n, extrList = lapply(X, range),
                                    family, mustart = NULL, inits = NULL, coefficients, linear.predictors,
@@ -454,13 +458,13 @@ SplineReg_GLM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), bas
     #   fitted.values = fitted.values,
     #   null.deviance = sum(family$dev.resids(Y, family$linkinv(offset), weights)), # Y ~ -1: no intercept
     #   weights = as.numeric(weights),
-    #   rank = qr(mm)$rank,  # or qr(basisMatrix2)$rank or qr(mm)$rank or rankMatrix(basisMatrix2) or length(coefficients)
+    #   rank = qr(mm)$rank,  # or qr(basisMatrix2)$rank or qr(mm)$rank or Matrix::rankMatrix(basisMatrix2) or length(coefficients)
     #   qr = qr(mm), # or qr(basisMatrix2)
     #   family = family,
     #   linear.predictors = linear.predictors,
     #   deviance =  sum(family$dev.resids(Y, fitted.values, weights)),
     #   prior.weights = weights, # the weights initially supplied
-    #   df.residual = as.numeric(nrow(basisMatrix2) - rankMatrix(basisMatrix2)), # residual degrees of freedom
+    #   df.residual = as.numeric(nrow(basisMatrix2) - Matrix::rankMatrix(basisMatrix2)), # residual degrees of freedom
     #   y = Y,
     #   terms = terms(mf),
     #   model = mf,
@@ -522,14 +526,14 @@ SplineReg_GLM_Multivar <- function(X, Y, Z = NULL, offset = rep(0, NROW(Y)), bas
   deviance <- tmp$deviance
   
   # Confidence intervals
-  CI <- CI(tmp, resid, prob = 0.95, basisMatrix, basisMatrix2, predicted,
+  ci <- ci(tmp, resid, prob = 0.95, basisMatrix, basisMatrix2, predicted,
            n_obs = length(Y), type = "glm", huang = FALSE)
   
-  out <- list(Theta = theta, Predicted = predicted,
-              Residuals = resid, RSS = deviance,
-              Basis = basisMatrix,
-              NCI = CI$NCI,
-              Polygon = list(Kn = polyknots_list, Thetas = theta[1:NCOL(basisMatrix)]),
+  out <- list(theta = theta, predicted = predicted,
+              residuals = resid, rss = deviance,
+              basis = basisMatrix,
+              nci = ci$nci,
+              polygon = list(kn = polyknots_list, thetas = theta[1:NCOL(basisMatrix)]),
               temporary = tmp, deviance = deviance)
   return(out)
 }
